pub enum DurationWeeksError {
ZeroWeeks,
}Expand description
Decision vocabulary for duration weeks error in training workflows.
Variants
ZeroWeeks
Zero weeks training operational signal for enrollment, curriculum, progress, package, or follow-up handling.